@@ -36,11 +36,6 @@ sub cmd_start {
 sub cmd_stop {
     my ($self, $dont_exit) = @_;
 
-    unless ($self->has_current_project) {
-        error_message("Could not find project\nUse --project or chdir into the project directory");
-        exit;
-    }
-
     my $task = App::TimeTracker::Data::Task->current($self->home);
     unless ($task) {
         return if $dont_exit;
@@ -311,15 +306,26 @@ sub cmd_plugins {
 
 sub cmd_commands {
     my $self = shift;
-
-    say "Available commands:";
+    
+    my @commands;
     foreach my $method ($self->meta->get_all_method_names) {
         next unless $method =~ /^cmd_/;
         $method =~ s/^cmd_//;
-        say "\t$method";
+        push(@commands,$method);
+    }
+
+    if ($self->can('autocomplete')
+        && $self->autocomplete) {
+        say join(' ',@commands);
+    } else {
+        say "Available commands:";
+        foreach my $command (@commands) {
+            say "\t$command";
+        }
     }
     exit;
 }
+
 sub _load_attribs_worked {
     my ($class, $meta) = @_;
     $meta->add_attribute('from'=>{
@@ -356,6 +362,15 @@ sub _load_attribs_worked {
     });
 
 }
+sub _load_attribs_commands {
+    my ($class, $meta) = @_;
+    $meta->add_attribute('autocomplete'=>{
+        isa=>'Bool',
+        is=>'ro',
+        default=>0,
+        documentation=>'Output for autocomplete',
+    });
+}
 sub _load_attribs_list {
     my ($class, $meta) = @_;
     $class->_load_attribs_worked($meta);
@@ -466,7 +481,7 @@ App::TimeTracker::Command::Core - App::TimeTracker Core commands
 
 =head1 VERSION
 
-version 2.012
+version 2.013
 
 =head1 CORE COMMANDS
 
