@@ -19,6 +19,12 @@ sub cmd_sync {
         $r->run(add=>$changed);
     }
 
+    foreach (qw(current previous)) {
+        unless (-e $self->home->file($_)) {
+            $r->run(rm=>$self->home->file($_)->stringify);
+        }
+    }
+
     $r->run(commit => '-m','synced on '.now());
 
     foreach my $cmd (qw(pull push)) {
@@ -41,7 +47,7 @@ App::TimeTracker::Command::SyncViaGit - App::TimeTracker SyncViaGit plugin
 
 =head1 VERSION
 
-version 2.012
+version 2.013
 
 =head1 DESCRIPTION
 
